.. role:: python(code)
   :language: python

####################################################
django-settings-local - Manage Django Local Settings
####################################################

|travis| |nbsp| |codecov| |nbsp| |rtd-badge| |nbsp| |pypi-version|

*****
Usage
*****

0. Installation
===============

The preferred instalation method is directly from pypi:

.. code:: console

   pip install -U django-settings-local


1. Quickstart
=============

In your Django project app directory:

.. code:: console

   dsl
   
2. Quickhelp
=============

Quick help from simple console script:

.. code:: console

   dsl -h
